@@ -58,6 +58,7 @@ if not hasattr(ipykernel, 'connect'):
 
 async function parseURL(app, browser, trans){
   const queryString = window.location.search;
+  const currentLocation = new URL(window.location);
   const urlParams = new URLSearchParams(queryString);
   const urls = urlParams.getAll("load");
   let lastFile = null;
@@ -98,6 +99,10 @@ async function parseURL(app, browser, trans){
       });
     }, 1000)
   }
+  // restore location, since jupyterlab will force double slashes into single
+  setTimeout(()=>{
+    window.history.pushState(null, '', currentLocation);
+  }, 1000)
 }
 class ImjoyExtension {
   constructor(jupyterBaseUrl) {
